@@ -183,7 +183,7 @@ class APPhot_Routine():
 
         self.log("-> calculating photometric errors\n")
         for i,mask in enumerate(annulus_aperture.to_mask(method="center")):
-            dat=mask.multiply(image)
+            dat=np.array(mask.multiply(image),dtype=float)
             dat=sigma_clip(dat[dat>0 & np.isfinite(dat)], sigma=sig_sky)
             if len(dat): ##sometimes all the surrounding pixels are nan OR above SIGSKY value??
                 #self.catalogue["sky"][i]=mode(dat)[0]
@@ -197,9 +197,12 @@ class APPhot_Routine():
         if dqflags is not None:
             self.log("-> flagging unlikely sources\n")
             for i, mask in enumerate(apertures.to_mask(method="center")):
-                dat=np.array(mask.multiply(dqflags),np.uint32)
-                if np.sum( dat & (DQ_DO_NOT_USE|DQ_SATURATED)): col[i]|=SRC_BAD
-                if np.sum( dat & DQ_JUMP_DET): col[i]|=SRC_JMP
+                _tmp=mask.multiply(dqflags)
+                if _tmp is not None:
+                    dat=np.array(_tmp,dtype=np.uint32)
+                    if np.sum( dat & (DQ_DO_NOT_USE|DQ_SATURATED)): col[i]|=SRC_BAD
+                    if np.sum( dat & DQ_JUMP_DET): col[i]|=SRC_JMP
+                #else: col[i]|=SRC_UKN
         self.catalogue.add_column(col)
         return self.catalogue
 
@@ -236,8 +239,8 @@ class APPhot_Routine():
 
         line=t_apcorr[(np.abs(t_apcorr["eefraction"]-encircled_energy)).argmin()]
         if verbose:
-            printf("Best matching encircled energy %.1f, with radius %g pixels\n"%(line["eefraction"],line["radius"]))
-            printf("Using aperture correction: %f\n"%line["apcorr"])
+            printf("-> best matching encircled energy %.1f, with radius %g pixels\n"%(line["eefraction"],line["radius"]))
+            printf("-> using aperture correction: %f\n"%line["apcorr"])
 
         return line["apcorr"], line["radius"]
 
@@ -281,7 +284,7 @@ class BackGround_Estimate_Routine(BackgroundBase):
 
         rlist=np.sqrt(peaks**0.7)*self.fwhm/1.5 ## <-- that works but hmm
         D=50
-        load=loading(len(self.sourcelist), msg="masking sources")
+        load=loading(len(self.sourcelist), msg="masking sources", res=10)
         for r,src in zip(rlist,self.sourcelist):
 
             rin=1.5*r
@@ -302,7 +305,8 @@ class BackGround_Estimate_Routine(BackgroundBase):
             _data[_Y,_X]=tmp
 
             load()
-            load.show() ## This will slow the thing down quite a lot
+            if self.verbose: load.show() ## This will slow the thing down quite a lot
+        if self.verbose: printf("-> estimating bgd2d\n")
         self.bgd=Background2D(_data, self.boxsize).background
         return self.bgd
 
@@ -335,8 +339,9 @@ class _fitmodel(LevMarLSQFitter):
     def __call__(self, *args, **kwargs):
         if self.grouper and self.load:
             self.load.setlen(self.grouper.ngroups)
-            self.load()
-            self.load.show()
+            if self.load is not None:
+                self.load()
+                self.load.show()
         return super().__call__(*args,**kwargs)
 
 
@@ -349,6 +354,7 @@ class PSFPhot_Routine(BasicPSFPhotometry):
             #sharplo=0.2, sharphi=1.0, roundlo=-1.0, roundhi=1.0,
             force_fit=False, dposition_threshold=2, background=None, wcs=None, verbose=1):
 
+        self.verbose=verbose
         self.force_fit=force_fit        
         self.dpos_thresh=dposition_threshold
 
@@ -358,7 +364,7 @@ class PSFPhot_Routine(BasicPSFPhotometry):
         
         if force_fit:
             psf_model.fixed.update( {"x_0":True,"y_0":True} )
-            fitter.load.msg+=" (forced)"
+            if fitter.load is not None: fitter.load.msg+=" (forced)"
 
         super().__init__(group_maker=group_maker, bkg_estimator=bkg_estimator,
                 psf_model=psf_model, fitshape=fitshape,
@@ -379,6 +385,7 @@ class PSFPhot_Routine(BasicPSFPhotometry):
             perror("Must include source list\n")
             return None
 
+        if self.verbose: printf("-> fitting %d sources\n"%len(init_guesses))
         cat=super().do_photometry(image, mask=mask, init_guesses=init_guesses, progress_bar=False)
         #cat=super().do_photometry(image, init_guesses=init_guesses)
 
