@@ -21,6 +21,7 @@ class StarbugBase(object):
     psfcatalogue=None
     residuals=None
     background=None
+    psf=None
     _image=None
     _nHDU=-1
     wcs=None
@@ -167,14 +168,18 @@ class StarbugBase(object):
         if not fname: fname=self.options["AP_FILE"]
         if os.path.exists(fname):
             self.detections=Table().read(fname,format="fits")#data=fp[1].data._get_raw_data())
-            self.detections["flag"]=Column(self.detections["flag"], dtype=np.uint16)
+            cn=self.detections.colnames
+
+            if "flag" in cn:
+                self.detections["flag"]=Column(self.detections["flag"], dtype=np.uint16)
+
             self.log("loaded AP_FILE='%s'\n"%fname)
 
-            cn=self.detections.colnames
             if not any( _ in cn for _ in ("xcentroid","ycentroid","x_0","y_0")):
                 if all( _ in cn for _ in ("RA","DEC")):
                     xy=self.wcs.all_world2pix(self.detections["RA"], self.detections["DEC"],0)
                     self.detections.add_columns(xy,names=("xcentroid","ycentroid"),indexes=[0,0])
+                    self.log("-> using RADEC coordinates\n")
                 else: perror("WARNING, unable to determine physical coordinates from detections table\n")
         else: perror("AP_FILE='%s' does not exists\n"%fname)
 
@@ -188,7 +193,33 @@ class StarbugBase(object):
         if os.path.exists(fname):
             self.background=fits.open(fname)[1]
             self.log("loaded BGD_FILE='%s'\n"%fname)
-        else: perror("BGD_FILE='%s' does not exists\n"%fname)
+        else: perror("BGD_FILE='%s' does not exist\n"%fname)
+
+    def load_psf(self,fname=None):
+        """
+        Load a PSF_FILE to be used during photometry
+        INPUT:
+            fname : psf.fits
+        """
+        status=0
+        if not fname:
+            fltr=starbug2.filters[self.filter]
+            dtname=self.info["DETECTOR"]
+            if dtname=="MULTIPLE":
+                if   fltr.instr==starbug2.NIRCAM and fltr.length==starbug2.SHORT: dtname="NRCA1"
+                elif fltr.instr==starbug2.NIRCAM and fltr.length==starbug2.LONG:  dtname="NRCALONG"
+                elif fltr.instr==starbug2.MIRI:  dtname=""
+            fname="%s/%s%s.fits"%(starbug2.DATDIR,self.filter,dtname)
+        if os.path.exists(fname):
+            fp=fits.open(fname)
+            self.psf=fp[1].data ####hmm
+            fp.close()
+            self.log("loaded PSF_FILE='%s'\n"%(fname))
+        else: 
+            perror("PSF_FILE='%s' does not exist\n"%fname)
+            status=1
+        return status
+
 
     def detect(self):
         """
@@ -196,7 +227,7 @@ class StarbugBase(object):
         Saves the result as a table self.detections
         """
         self.log("Detecting Sources\n")
-        if self._image and self.filter:
+        if self.image and self.filter:
             #FWHM=starbug2.filters[self.filter][2]
             FWHM=starbug2.filters[self.filter].pFWHM
             detector=Detection_Routine( sig_src=self.options["SIGSRC"],
@@ -260,8 +291,8 @@ class StarbugBase(object):
         skyin= self.options["SKY_RIN"]
         skyout=self.options["SKY_ROUT"]
 
-        if   self.info["INSTRUME"]=="NIRCAM": fname="%s/apcorr_nircam.fits"%self.options["PSFDIR"]
-        elif self.info["INSTRUME"]=="MIRI":   fname="%s/apcorr_miri.fits"%self.options["PSFDIR"]
+        if   self.info["INSTRUME"]=="NIRCAM": fname="%s/apcorr_nircam.fits"%starbug2.DATDIR
+        elif self.info["INSTRUME"]=="MIRI":   fname="%s/apcorr_miri.fits"%starbug2.DATDIR
         else: perror("No apcorr file available for instrument\n")
 
         if self.options["FIT_APP_R"]:
@@ -343,23 +374,26 @@ class StarbugBase(object):
             perror("unable to run photometry: no background estimation loaded\n")
             return
 
-        if self._image and self.filter:
-            self.log("Running PSF Photometry")
+        if self.psf is None and self.load_psf(self.options["PSF_FILE"]):
+            perror("unable to run photometry: no PSF loaded\n")
+            return
+
+        if self.image:
+            self.log("Running PSF Photometry\n")
 
             ###################################
             # Collect relevent files and data #
             ###################################
 
-            image=self._image["SCI"].data.copy() / self._image["SCI"].header["PHOTMJSR"] #https://spacetelescope.github.io/jdat_notebooks/notebooks/psf_photometry/NIRCam_PSF_Photometry_Example.html
-            bgd = self.background.data.copy()# / self._image["SCI"].header["PHOTMJSR"] 
+            image=self.image.data.copy()/ self.image.header["PHOTMJSR"] #https://spacetelescope.github.io/jdat_notebooks/notebooks/psf_photometry/NIRCam_PSF_Photometry_Example.html
+            bgd = self.background.data.copy() / self.image.header["PHOTMJSR"] 
 
-            fname=os.path.expandvars("%s/%s%s.fits"%(self.options["PSFDIR"], self.filter, self.info["DETECTOR"]))
-            self.log(" <-- %s\n"%fname)
-            with fits.open(fname) as fp:
-                psf_model=FittableImageModel(fp[1].data)
-                #psf_model=EPSFModel(fp[1].data)
-                size=psf_model.shape[0]
-                if not size%2: size-=1
+            psf_model=FittableImageModel(self.psf)
+            #psf_model=EPSFModel(fp[1].data)
+            if self.options["PSF_SIZE"]>0: size=int(self.options["PSF_SIZE"])
+            else: size=psf_model.shape[0]
+            if not size%2: size-=1
+            self.log("-> psf size: %d\n"%size)
 
             #########################
             # Sort out Init guesses #
@@ -371,12 +405,14 @@ class StarbugBase(object):
 
             init_guesses=init_guesses[ init_guesses["x_0"]>=0 ]
             init_guesses=init_guesses[ init_guesses["y_0"]>=0 ]
-            init_guesses=init_guesses[ init_guesses["x_0"]<self._image["SCI"].header["NAXIS1"]]
-            init_guesses=init_guesses[ init_guesses["y_0"]<self._image["SCI"].header["NAXIS2"]]
+            init_guesses=init_guesses[ init_guesses["x_0"]<self.image.header["NAXIS1"]]
+            init_guesses=init_guesses[ init_guesses["y_0"]<self.image.header["NAXIS2"]]
             init_guesses=init_guesses[["x_0","y_0","flux",self.filter, "flag"]]
-            init_guesses.rename_column("flux","flux_0")
+            init_guesses.remove_column("flux")
+            #init_guesses.rename_column("flux","flux_0")
             init_guesses.rename_column(self.filter,"ap_%s"%self.filter)
-            init_guesses=init_guesses[init_guesses["flux_0"]>0]
+            #init_guesses=init_guesses[init_guesses["flux_0"]>0]
+            #init_guesses.remove_column("flux_0")
             
             ###########
             # Run Fit #
@@ -386,12 +422,10 @@ class StarbugBase(object):
             _fixpsf_cat=None
 
             if not self.options["FORCE_POS"]:
-                dpos= self.options["DPOS_THRESH"] / np.sqrt( self._image["SCI"].header["PIXAR_A2"])
+                dpos= self.options["DPOS_THRESH"] / np.sqrt( self.image.header["PIXAR_A2"])
                 self.log("-> position fit threshold [pix]: %.2g\n"%dpos)
-
-                phot=PSFPhot_Routine(self.options["CRIT_SEP"], psf_model, size, background=bgd, force_fit=0)
+                phot=PSFPhot_Routine(self.options["CRIT_SEP"], psf_model, size, background=bgd, force_fit=0, verbose=self.options["VERBOSE"])
                 _psf_cat=phot(image,init_guesses=init_guesses)
-                print(_psf_cat)
                 d = (_psf_cat["x_0"]-_psf_cat["x_fit"])**2.0 + (_psf_cat["y_0"]-_psf_cat["y_fit"])**2.0
                 ii=np.where(d>=dpos**2.0)
                 init_guesses=init_guesses[ii]
@@ -399,7 +433,7 @@ class StarbugBase(object):
                 if len(init_guesses): self.log("-> number bad position fits: %d\n"%len(init_guesses))
 
             if len(init_guesses):
-                phot=PSFPhot_Routine(self.options["CRIT_SEP"], psf_model, size, background=bgd, force_fit=1)
+                phot=PSFPhot_Routine(self.options["CRIT_SEP"], psf_model, size, background=bgd, force_fit=1, verbose=self.options["VERBOSE"])
                 _fixpsf_cat=phot(image,init_guesses=init_guesses)
                 _fixpsf_cat["flag"] |= starbug2.SRC_FIX
 
@@ -467,7 +501,7 @@ class StarbugBase(object):
         >>> This needs to get the background loaded into it somewhere!!
         """
 
-        fname=os.path.expandvars("%s/%s.fits"%(self.options["PSFDIR"], self.filter))
+        fname=os.path.expandvars("%s/%s.fits"%(starbug2.DATDIR, self.filter))
         with fits.open(fname) as fp:
             psf_model=DiscretePRF(fp[0].data)
 
@@ -478,7 +512,7 @@ class StarbugBase(object):
                                     sharphi=self.options["SHARP_HI"],
                                     roundlo=self.options["ROUND_LO"],
                                     roundhi=self.options["ROUND_HI"],
-                                    wcs=WCS(self._image[1].header),
+                                    wcs=WCS(self.image.header),
                                     verbose=0)
 
         phot=PSFPhot_Routine(   self.options["CRIT_SEP"],
@@ -491,12 +525,12 @@ class StarbugBase(object):
                                 sharphi=self.options["SHARP_HI"],
                                 roundlo=self.options["ROUND_LO"],
                                 roundhi=self.options["ROUND_HI"],
-                                wcs=WCS(self._image[1].header),
+                                wcs=WCS(self.image.header),
                                 verbose=0)
 
         art=ArtificialStar_Routine(detector, phot, psf_model)
         self.log("Artificial Star Testing (n=%d)\n"%(self.options["NUMBER_ARTIFICIAL_STARS"]))
-        result=art.run(self._image[1].data, ntests=self.options["NUMBER_ARTIFICIAL_STARS"], flux_range=(self.options["MIN_FLUX"], self.options["MAX_FLUX"]),
+        result=art.run(self.image.data, ntests=self.options["NUMBER_ARTIFICIAL_STARS"], flux_range=(self.options["MIN_FLUX"], self.options["MAX_FLUX"]),
                 subimage_size=self.options["SUBIMAGE_SIZE"], separation_thresh=self.options["SEPARATION_THRESH"], fwhm=starbug2.filters[self.filter].pFWHM)
         export_table(result, "/tmp/artificialstars.fits")
 
@@ -563,17 +597,18 @@ class StarbugBase(object):
             perror("Unknown filter '%s'\n"%self.filter)
             status=1
 
-        dname = os.path.expandvars(self.options["PSFDIR"])
+        dname = os.path.expandvars(starbug2.DATDIR)
         if not os.path.exists(dname):
             warn()
-            perror("Unable to locate PSFDIR='%s'\n"%dname)
+            perror("Unable to locate STARBUG_DATDIR='%s'\n"%dname)
             status=1
 
         else:
-            if not os.path.exists("%s/%s%s.fits"%(dname, self.filter, self.info["DETECTOR"])):
-                warn()
-                perror("Unable to locate filter PSF for '%s'\n"%self.filter)
-                status=1
+            pass
+            #if not os.path.exists("%s/%s%s.fits"%(dname, self.filter, self.info["DETECTOR"])):
+            #        warn()
+            #        perror("Unable to locate filter PSF for '%s'\n"%self.filter)
+            #        status=1
         
         if not os.path.exists((dname:=os.path.expandvars(self.options["OUTDIR"]))):
             warn()
